@@ -18,11 +18,11 @@ Mojo::Pg::Che - mix of parent Mojo::Pg and DBI.pm
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 =head1 SYNOPSIS
@@ -55,7 +55,7 @@ our $VERSION = '0.03';
     my $sth = $pg->prepare_cached('select ...');
     
     # Non-blocking query sth
-    my $result = $pg->query($sth, undef, @bind, sub {my ($db, $err, $result) = @_; ...});
+    my $r = $pg->query($sth, undef, @bind, sub {my ($db, $err, $result) = @_; ...});
     Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
     
     # Result non-blocking query sth
@@ -121,13 +121,55 @@ Parent method of L<Mojo::Pg#new>
 
 DBI-style of new object instance. See L<DBI#connect>
 
-=head3 query
+=head2 query
 
 Is same as L<Mojo::Pg::Database#query>.
 
-Blocking query without attr B<pg_async>.
+Blocking query without attr B<Async> or callback.
 
-Non-blocking query with attr B<pg_async>.
+Non-blocking query with attr B<Async> or callback.
+
+Statement handler as first param is allow.
+
+=head2 db
+
+Parent method of L<Mojo::Pg#db>.
+
+=head2 prepare
+
+Prepare and return DBI statement handler for query string.
+
+=head2 prepare_cached
+
+Prepare and return DBI cached statement handler for query string.
+
+=head2 selectrow_array
+
+DBI style quering. See L<DBI#selectrow_array>. Blocking|non-blocking, query string|statement handler.
+
+=head2 selectrow_arrayref
+
+DBI style quering. See L<DBI#selectrow_arrayref>. Blocking|non-blocking, query string|statement handler.
+
+=head2 selectrow_hashref
+
+DBI style quering. See L<DBI#selectrow_hashref>. Blocking|non-blocking, query string|statement handler.
+
+=head2 selectall_arrayref
+
+DBI style quering. See L<DBI#selectall_arrayref>. Blocking|non-blocking, query string|statement handler.
+
+=head2 selectall_hashref
+
+DBI style quering. See L<DBI#selectall_hashref>. Blocking|non-blocking, query string|statement handler.
+
+=head2 selectcol_arrayref
+
+DBI style quering. See L<DBI#selectcol_arrayref>. Blocking|non-blocking, query string|statement handler.
+
+=head2 do
+
+DBI style quering. See L<DBI#do>. Blocking|non-blocking, query string|statement handler.
 
 =head1 AUTHOR
 
@@ -193,8 +235,8 @@ sub query {
   
   #~ $sth ||= $self->prepare($query, $attrs, 3); ?????
   
-  if ($sth) {$result = $self->db($sth->{Database})->query_sth($sth, @bind, $cb ? ($cb) : ());}
-  else {$result = $self->db->query_string($query, $attrs, @bind, $cb ? ($cb) : (),);}
+  if ($sth) {$result = $self->db($sth->{Database})->execute_sth($sth, @bind, $cb ? ($cb) : ());}
+  else {$result = $self->db->execute_string($query, $attrs, @bind, $cb ? ($cb) : (),);}
   
   Mojo::IOLoop->start if $async && not(Mojo::IOLoop->is_running);
 
